aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--engines/sci/graphics/windowmgr.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/sci/graphics/windowmgr.cpp b/engines/sci/graphics/windowmgr.cpp
index 374efb2b30..faa598326c 100644
--- a/engines/sci/graphics/windowmgr.cpp
+++ b/engines/sci/graphics/windowmgr.cpp
@@ -63,9 +63,9 @@ void WindowMgr::init(Common::String gameId) {
// will work, but some scripts seem to check for 0 and initialize the variable again in that case
// resulting in problems.
- // Jones sierra sci was called with parameter -Nw 0 0 200 320
- // this actually meant not skipping the first 10 pixellines in windowMgrPort
- if (gameId == "jones")
+ // Jones, Slater and Hoyle 3 were called with parameter -Nw 0 0 200 320.
+ // This actually meant not skipping the first 10 pixellines in windowMgrPort
+ if (gameId == "jones" || gameId == "slater" || gameId == "hoyle3")
offTop = 0;
_gfx->OpenPort(_wmgrPort);